==> mktcenter-service-threetree-1.0-20250918.102922-20-sources.jar: com/bizvane/mktcenterservice/models/vo/tree3/respvo/GetDetailActivityCertificationRespVO.java <==
package com.bizvane.mktcenterservice.models.vo.tree3.respvo;

import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.MktActivityCertificationRecordVo;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.util.Date;
import java.util.List;

@Data
public class GetDetailActivityCertificationRespVO {

    @ApiModelProperty(value = "认证活动ID")
    private Long mktActivityCertificationId;

    private Long sysCompanyId;

    private Long sysBrandId;

    @ApiModelProperty(value = "认证活动名称")
    private String activityName;

    @ApiModelProperty(value = "认证活动开始时间")
    private Date startTime;

    @ApiModelProperty(value = "认证活动结束时间")
    private Date endTime;

    @ApiModelProperty(value = "省")
    private String province;

    @ApiModelProperty(value = "市")
    private String city;

    @ApiModelProperty(value = "区")
    private String district;

    @ApiModelProperty(value = "详细地址")
    private String detailedAddress;

    @ApiModelProperty(value = "经度")
    private String addressLon;

    @ApiModelProperty(value = "纬度")
    private String addressLat;

    @ApiModelProperty(value = "认证活动图片")
    private String activityImg;

    @ApiModelProperty(value = "认证活动说明")
    private Integer issuanceType;

    @ApiModelProperty(value = "认证类型列表")
    private List<GetDetailCertificationTypeRespVO> certificationTypeList;

    @ApiModelProperty(value = "主办方机构编码")
    private String hostOrgCode;

    @ApiModelProperty(value = "主办方机构名称")
    private String undertakingUnitName;

    @ApiModelProperty(value = "认证活动详情")
    private String activityDetail;

    @ApiModelProperty(value = "状态")
    private Integer state;


    private String onlineOrgCode;

    private String onlineOrgName;

    @ApiModelProperty(value = "报名二维码")
    private String applyQrCode;

    @ApiModelProperty(value = "签到二维码")
    private String signInQrCode;

    @ApiModelProperty(value = "浏览量")
    private Long viewCount;

    @ApiModelProperty(value = "报名人数")
    private Long applyCount;

    @ApiModelProperty(value = "签到人数")
    private Long signInCount;

    @ApiModelProperty(value = "认证人数")
    private Long certificationCount;

    @ApiModelProperty(value = "认证率")
    private String certificationRate;

    @ApiModelProperty(value = "签到状态（1 已签到  0未签到)")
    private Integer signStatus;
    @ApiModelProperty(value = "申请状态 （0未报名 1-已报名）")
    private Integer applyState;
    @ApiModelProperty(value = "报名信息")
    private MktActivityCertificationRecordVo mktActivityCertificationRecordVo;
}

==> mktcenter-service-threetree-1.0-20250924.095103-22-sources.jar: com/bizvane/mktcenterservice/models/vo/tree3/respvo/GetDetailActivityCertificationRespVO.java <==
package com.bizvane.mktcenterservice.models.vo.tree3.respvo;

import com.bizvane.mktcenterservice.models.vo.tree3.reqvo.MktActivityCertificationRecordVo;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.util.Date;
import java.util.List;

@Data
public class GetDetailActivityCertificationRespVO {

    @ApiModelProperty(value = "认证活动ID")
    private Long mktActivityCertificationId;

    private Long sysCompanyId;

    private Long sysBrandId;

    @ApiModelProperty(value = "认证活动名称")
    private String activityName;

    @ApiModelProperty(value = "认证活动开始时间")
    private Date startTime;

    @ApiModelProperty(value = "认证活动结束时间")
    private Date endTime;

    @ApiModelProperty(value = "省")
    private String province;

    @ApiModelProperty(value = "市")
    private String city;

    @ApiModelProperty(value = "区")
    private String district;

    @ApiModelProperty(value = "详细地址")
    private String detailedAddress;

    @ApiModelProperty(value = "经度")
    private String addressLon;

    @ApiModelProperty(value = "纬度")
    private String addressLat;

    @ApiModelProperty(value = "认证活动图片")
    private String activityImg;

    @ApiModelProperty(value = "认证活动说明")
    private Integer issuanceType;

    private List<Long> certificationTypeIdList;

    @ApiModelProperty(value = "认证类型列表")
    private List<GetDetailCertificationTypeRespVO> certificationTypeList;

    @ApiModelProperty(value = "主办方机构编码")
    private String hostOrgCode;

    @ApiModelProperty(value = "主办方机构名称")
    private String hostOrgName;

    @ApiModelProperty(value = "承办方机构名称")
    private List<String> undertakingUnitNameList;

    @ApiModelProperty(value = "认证活动详情")
    private String activityDetail;

    @ApiModelProperty(value = "状态")
    private Integer state;


    private String onlineOrgCode;

    private String onlineOrgName;

    @ApiModelProperty(value = "报名二维码")
    private String applyQrCode;

    @ApiModelProperty(value = "签到二维码")
    private String signInQrCode;

    @ApiModelProperty(value = "签到状态（1 已签到  0未签到)")
    private Integer signStatus;
    @ApiModelProperty(value = "申请状态 （0未报名 1-已报名）")
    private Integer applyState;
    @ApiModelProperty(value = "报名信息")
    private MktActivityCertificationRecordVo mktActivityCertificationRecordVo;
}
